toxSummary_app: Run toxSummary app
Description
Run toxSummary app
Usage
toxSummary_app(
database_path = NULL,
studyid_file = NULL,
save_file_path = NULL,
where_to_run = "local"
)
Value
function run the app.
Arguments
- database_path
Optional, character
file path for database
- studyid_file
Optional, character
file path for studyid
- save_file_path
optional, character
directory where files will be saved when app create any files.
if NULL, all the files will be created in temp directory.
- where_to_run
Optional, character
where app will be running. Default is "local". Should use "rsconnect"
when deploy to rsconnect.
Examples
Run this codeif(interactive()) {
toxSummary_app()
}
Run the code above in your browser using DataLab